pytest-houdini
==============

[![PyPI version](https://img.shields.io/pypi/v/pytest-houdini)](https://pypi.org/pypi/pytest-houdini)
[![Tests](https://github.com/captainhammy/pytest-houdini/actions/workflows/tests.yml/badge.svg)](https://github.com/captainhammy/pytest-houdini/actions/workflows/tests.yml)
[![Documentation Status](https://readthedocs.org/projects/pytest-houdini/badge/?version=latest)](https://pytest-houdini.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/github/captainhammy/pytest-houdini/graph/badge.svg?token=OVVZFQVSZR)](https://codecov.io/github/captainhammy/pytest-houdini)

pytest-houdini is a plugin for [pytest](http://pytest.org) which provides a number of fixtures and utilities for use
with testing code run by [Houdini](http://sidefx.com).
